# How to contribute

#### Setup
1. Make sure your setup reflects the `Development` section of the installation instructions.

1. Create a branch to isolate your work.  

        git checkout -b my-cool-new-feature-or-bug-fix

1. Create a Merge Request and wait for a maintainer's feedback.

#### Guidelines
1. You are encouraged to use [TDD](https://en.wikipedia.org/wiki/Test-driven_development) during the process.
2. Code without tests does not get merged.
3. ???
4. Profit.